<?php
    /**
     * ReduxFramework Sample Config File
     * For full documentation, please visit: http://docs.reduxframework.com/
     */

    if ( ! class_exists( 'Redux' ) ) {
        return;
    }


    // This is your option name where all the Redux data is stored.
    $opt_name = "bionick_wp";

    // This line is only for altering the demo. Can be easily removed.
    $opt_name = apply_filters( 'bionick_wp/opt_name', $opt_name );


    /**
     * ---> SET ARGUMENTS
     * All the possible arguments for Redux.
     * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
     * */

    $theme = wp_get_theme(); // For use with some settings. Not necessary.

    $args = array(
        // TYPICAL -> Change these values as you need/desire
        'opt_name'             => $opt_name,
		'class'                => 'admin-color-pimax',
        // This is where your data is stored in the database and also becomes your global variable name.
        'display_name'         => $theme->get( 'Name' ),
        // Name that appears at the top of your panel
        'display_version'      => $theme->get( 'Version' ),
        // Version that appears at the top of your panel
        'menu_type'            => 'menu',
        //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
        'allow_sub_menu'       => true,
        // Show the sections below the admin menu item or not
        'menu_title'           => esc_attr__( 'Bionick Options', 'bionickwp' ),
        'page_title'           => esc_attr__( 'Bionick Options', 'bionickwp' ),
        // You will need to generate a Google API key to use this feature.
        // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
        'google_api_key'       => 'AIzaSyCN8bSGZHdbSOXu0HbhXf8j0SnswTmbCNw',
        // Set it you want google fonts to update weekly. A google_api_key value is required.
        'google_update_weekly' => false,
        // Must be defined to add google fonts to the typography module
        'async_typography'     => false,
        // Use a asynchronous font on the front end or font string
        //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
        'admin_bar'            => true,
        // Show the panel pages on the admin bar
        'admin_bar_icon'       => 'dashicons-portfolio',
        // Choose an icon for the admin bar menu
        'admin_bar_priority'   => 50,
        // Choose an priority for the admin bar menu
        'global_variable'      => '',
        // Set a different name for your global variable other than the opt_name
        'dev_mode'             => false,
        // Show the time the page took to load, etc
        'update_notice'        => false,
        // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
        'customizer'           => true,
        // Enable basic customizer support
        //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
        //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

        // OPTIONAL -> Give you extra features
        'page_priority'        => null,
        // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
        'page_parent'          => 'themes.php',
        // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
        'page_permissions'     => 'manage_options',
        // Permissions needed to access the options panel.
        'menu_icon'            => '',
        // Specify a custom URL to an icon
        'last_tab'             => '',
        // Force your panel to always open to a specific tab (by id)
        'page_icon'            => 'icon-themes',
        // Icon displayed in the admin panel next to your menu_title
        'page_slug'            => '',
        // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
        'save_defaults'        => true,
        // On load save the defaults to DB before user clicks save or not
        'default_show'         => false,
        // If true, shows the default value next to each field that is not the default value.
        'default_mark'         => '',
        // What to print by the field's title if the value shown is default. Suggested: *
        'show_import_export'   => true,
        // Shows the Import/Export panel when not used as a field.

        // CAREFUL -> These options are for advanced use only
        'transient_time'       => 60 * MINUTE_IN_SECONDS,
        'output'               => true,
        // Global shut-off for dynamic CSS output by the bionick. Will also disable google fonts output
        'output_tag'           => true,
        // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
        // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

        // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
        'database'             => '',
        // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
        'use_cdn'              => true,
        // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

        // HINTS
        'hints'                => array(
            'icon'          => 'el el-question-sign',
            'icon_position' => 'right',
            'icon_color'    => 'lightgray',
            'icon_size'     => 'normal',
            'tip_style'     => array(
                'color'   => 'red',
                'shadow'  => true,
                'rounded' => false,
                'style'   => '',
            ),
            'tip_position'  => array(
                'my' => 'top left',
                'at' => 'bottom right',
            ),
            'tip_effect'    => array(
                'show' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'mouseover',
                ),
                'hide' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'click mouseleave',
                ),
            ),
        )
    );

    // Panel Intro text -> before the form
    if ( ! isset( $args['global_variable'] ) || $args['global_variable'] !== false ) {
        if ( ! empty( $args['global_variable'] ) ) {
            $v = $args['global_variable'];
        } else {
            $v = str_replace( '-', '_', $args['opt_name'] );
        }
        $args['intro_text'] = sprintf( esc_attr__( '', 'bionickwp' ), $v );
    } else {
        $args['intro_text'] = esc_attr__( '', 'bionickwp' );
    }

    // Add content after the form.
    $args['footer_text'] = esc_attr__( '', 'bionickwp' );

    Redux::setArgs( $opt_name, $args );

    $tabs = array(
        array(
            'id'      => 'redux-help-tab-1',
            'title'   => esc_attr__( 'Theme Information 1', 'bionickwp' ),
            'content' => esc_attr__( '<p>This is the tab content, HTML is allowed.</p>', 'bionickwp' )
        ),
        array(
            'id'      => 'redux-help-tab-2',
            'title'   => esc_attr__( 'Theme Information 2', 'bionickwp' ),
            'content' => esc_attr__( '<p>This is the tab content, HTML is allowed.</p>', 'bionickwp' )
        )
    );
    Redux::setHelpTab( $opt_name, $tabs );

    // Set the help sidebar
    $content = esc_attr__( '<p>This is the sidebar content, HTML is allowed.</p>', 'bionickwp' );
    Redux::setHelpSidebar( $opt_name, $content );

    // -> START Basic Fields
	            Redux::setSection( $opt_name, array(
                    'icon'   => 'el-icon-home-alt',
                    'title'  => esc_attr__( 'General Settings', 'bionickwp' ),
                    'fields' => array(
					
					array(
							'id' => 'textlogo',
							'type' => 'button_set',
							'title' => esc_html__('Select Logo Format', 'bionickwp'),
							'subtitle' => esc_html__('', 'bionickwp'),
							'desc' => '',
							'options' => array(
									'st1'=> esc_html__('Text Logo', 'bionickwp'),
									'st2' => esc_html__('Image Logo', 'bionickwp'),
									
							),
							'default'  => 'st1'
					),
					 
					array(
							'id' => 'logopic',
							'type' => 'media',
							'compiler' => 'true',
							'title' => esc_html__('Logo Image', 'bionickwp'),
							'subtitle' => esc_html__('Image Size 200px X 70px', 'bionickwp'),
							'required' => array('textlogo', '=' , 'st2')
					),
					array(
                    'id' => 'logo_padding',
                    'type' => 'spacing',
                    'units' => array('px','em','%'),
                    'output' => array('.logo-holder img'), // An array of CSS selectors to apply this font style to
                    'mode' => 'padding', // absolute, padding, margin, defaults to padding
                    'title' => esc_attr__('Logo Padding', 'bionickwp'),
                    'default' => array('padding-top' => '', 'padding-right' => "", 'padding-bottom' => '', 'padding-left' => ''),
					'required' => array('textlogo', '=' , 'st2')
					),						
					$fields = array(
							'id'       => 'opt_logo_dimensions',
							'type'     => 'dimensions',
							'units'    => array('em','px','%'),
							'output' => array('.logo-holder img'),
							'title'    => esc_html__('Logo Size', 'bionickwp'),
							'subtitle' => esc_html__('.', 'bionickwp'),
							'desc'     => esc_html__('Optional', 'bionickwp'),
							'default'  => array(
								'Width'   => '110', 
								'Height'  => '22'
							),
							'required' => array('textlogo', '=' , 'st2')
				    ),					
					array(
							'id' => 'logotext',
							'type' => 'text',
							'title' => esc_html__('Logo Text ', 'bionickwp'),
							'subtitle' => esc_html__('', 'bionickwp'),
							'required' => array('textlogo', '=' , 'st1')
					
					),					
											
					array(
							'id' => 'ht-home-wid-twit',
							'type' => 'info',
		                    'notice' => true,
		                    'style' => 'info',
							'title' => esc_attr__('Portfolio Options', 'bionickwp'),
							
					),					
					
					array(
							'id' => 'port-page-link',
							'type' => 'text',
							'title' => esc_attr__('Portfolio Page Link', 'bionickwp'),
							'subtitle' => esc_attr__('Write portfolio page link url.', 'bionickwp'),
							'default' => '',
							'validate' => 'url'
							
					),	
					array(
							'id' => 'prf-project-filter-all',
							'type' => 'text',
							'title' => esc_attr__('All Filter Text', 'bionickwp'),
							'subtitle' => esc_attr__('Change/Repalce portfolio post "ALL" text here.', 'bionickwp'),
							'default' => '',
							
					),					
					
				  )
                ) );									
				
				Redux::setSection( $opt_name, array(
                    'icon'   => 'el-icon-cogs',
                    'title'  => esc_attr__( 'Blog Settings', 'bionickwp' ),
                    'fields' => array(					

			        array(
							'id' => 'layout-blog-page',
							'type' => 'image_select',
							'title' => esc_attr__('Layout Style', 'bionickwp'),
							'subtitle' => esc_attr__('Choose layout style for blog single, archives, category, tag & search page.', 'bionickwp'),
							'options' => array(
							        'left'=> __( get_template_directory_uri().'/includes/metaboxes/img/sidebar-left.png', 'bionickwp' ),
									'default'=> __( get_template_directory_uri().'/includes/metaboxes/img/default.png', 'bionickwp' ),
									'right'=> __( get_template_directory_uri().'/includes/metaboxes/img/sidebar-right.png', 'bionickwp' ),
									
							),
							'default'  => 'default'
					),
					
                     array(
							'id' => 'blog-single-image',
							'type' => 'media',
							'compiler' => 'true',
							'title' => esc_attr__('Section Image', 'bionickwp'),
							'subtitle' => esc_attr__('Upload a 800px X 1200px .jpg or .png size image.', 'bionickwp'),
							'required' => array('layout-blog-page', '=' , 'default')
					),	

							array(
							'id' => 'blog-section-title',
							'type' => 'text',
							'title' => esc_attr__('Section Title Text', 'bionickwp'),
							'subtitle' => esc_attr__('Write section title for blog single, archives, category, tag & search page title here.', 'bionickwp'),
							'default' => '',
							'required' => array('layout-blog-page', '=' , 'default')
							
					),					
					
			        array(
							'id' => 'header-search-box',
							'type' => 'button_set',
							'title' => esc_attr__('Header Search Box', 'bionickwp'),
							'default'  => 'yes',
							'options' => array(
									'yes'=> esc_attr__('Enable', 'bionickwp'),
									'no'=> esc_attr__('Disable', 'bionickwp'),
							),
							
					),						

			        array(
							'id' => 'blog-page-title-on-off',
							'type' => 'button_set',
							'title' => esc_attr__('Page Title', 'bionickwp'),
							'default'  => 'yes',
							'options' => array(
									'yes'=> esc_attr__('Enable', 'bionickwp'),
									'no'=> esc_attr__('Disable', 'bionickwp'),
							),
							
					),					
					
						array(
							'id' => 'blog-page-title',
							'type' => 'text',
							'title' => esc_attr__('Page Title Text', 'bionickwp'),
							'subtitle' => esc_attr__('Write title for blog page title here.', 'bionickwp'),
							'default' => '',
							'required' => array('blog-page-title-on-off', '=' , 'yes')
							
					),	

						array(
							'id' => 'blog-page-subtitle',
							'type' => 'text',
							'title' => esc_attr__('Page Subtitle Text', 'bionickwp'),
							'subtitle' => esc_attr__('Write subtitle for blog page here.', 'bionickwp'),
							'default' => '',
							'required' => array('blog-page-title-on-off', '=' , 'yes')
							
					),					

			        array(
							'id' => 'blog-share',
							'type' => 'button_set',
							'title' => esc_attr__('Post Social Share', 'bionickwp'),
							'default'  => 'yes',
							'options' => array(
									'yes'=> esc_attr__('Enable', 'bionickwp'),
									'no'=> esc_attr__('Disable', 'bionickwp'),
							),
							
					),
					
					array(
							'id' => 'blog-share-title',
							'type' => 'text',
							'title' => esc_attr__('Share Text', 'bionickwp'),
							'default' => '',
							'required' => array('blog-share', '=' , 'yes')
							
					),

					array(
							'id' => 'blog-posted-by',
							'type' => 'text',
							'title' => esc_attr__('Posted By Text', 'bionickwp'),
							'subtitle' => esc_attr__('Change/Repalce blog post "Posted By" text here.', 'bionickwp'),							
							'default' => '',
							
					),	
					array(
							'id' => 'blog-read-more',
							'type' => 'text',
							'title' => esc_attr__('Continue Reading Text', 'bionickwp'),
							'subtitle' => esc_attr__('Change/Repalce blog post "Continue reading ..." text here.', 'bionickwp'),							
							'default' => '',
							
					),	

					array(
							'id' => 'arch-page-title',
							'type' => 'text',
							'title' => esc_attr__('Archive Page Title', 'bionickwp'),
							'subtitle' => esc_attr__('Write header title for blog archive page title here. Ex: Archive', 'bionickwp'),
							'default' => '',
							'required' => array('blog-page-title-on-off', '=' , 'yes')
					),	

					array(
							'id' => 'cat-page-title',
							'type' => 'text',
							'title' => esc_attr__('Category Page Title', 'bionickwp'),
							'subtitle' => esc_attr__('Write header title for blog category page title here. Ex: Category', 'bionickwp'),
							'default' => '',
							'required' => array('blog-page-title-on-off', '=' , 'yes')
					),	

					array(
							'id' => 'tag-page-title',
							'type' => 'text',
							'title' => esc_attr__('Tag Page Title', 'bionickwp'),
							'subtitle' => esc_attr__('Write header title for blog tag page title here. Ex: Tag', 'bionickwp'),
							'default' => '',
							'required' => array('blog-page-title-on-off', '=' , 'yes')
					),						
					
                    )
                ));
				
				Redux::setSection( $opt_name, array(
                    'icon'   => 'el-icon-brush',
                    'title'  => esc_attr__( 'Styling', 'bionickwp' ),
                    'fields' => array(
					
						array(
                            'id'       => 'opt-theme-style',
                            'type'     => 'color',
                            'title'    => esc_attr__( 'Theme Color', 'bionickwp' ),
                            'subtitle' => esc_attr__( 'Only color validation can be done on this field type.', 'bionickwp' ),
                            'desc'     => esc_attr__( '', 'bionickwp' ),
                            //'regular'   => false, // Disable Regular Color
                            //'hover'     => false, // Disable Hover Color
                            //'active'    => false, // Disable Active Color
                            //'visited'   => true,  // Enable Visited Color
                            
                        ),						
					array(
                        'id'        => 'custom-css',
                        'type'      => 'ace_editor',
                        'title'     => esc_attr__('Custom CSS', 'bionickwp'),
                        'subtitle'  => esc_attr__('Write your CSS code here.', 'bionickwp'),
                        'mode'      => 'css',
						'theme'    => 'monokai',
                        
                    ),
																		
					)
               ) );				
				
            Redux::setSection( $opt_name, array(
                    'icon'   => 'el-icon-text-width',
                    'title'  => esc_attr__( 'Typography', 'bionickwp' ),
                    'fields' => array(     
						array(
                            'id'          => 'typo_body',
                            'type'        => 'typography', 
                            'title'       => __('Body', 'bionickwp'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('body'),
                            'units'       =>'px',
                            'line-height'       =>false,
                            'subtitle'    => esc_attr__('Specify the Body Text font properties.', 'bionickwp'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),						
						array(
			                'id' => 'notice_critical11',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_attr__('Entry Headings', 'bionickwp'),
			                'desc' => esc_attr__('Entry Headings in posts/pages', 'bionickwp')
			            ),					
                        array(
                            'id'          => 'typography-h1',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('H1', 'bionickwp'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('h1'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the Heading font properties.', 'bionickwp'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),	
                        array(
                            'id'          => 'typography-h2',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('H2', 'bionickwp'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('h2'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the Heading font properties.', 'bionickwp'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),      
                        ),
                        array(
                            'id'          => 'typography-h3',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('H3', 'bionickwp'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('h3'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the Heading font properties.', 'bionickwp'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),	
                        	
                        array(
                            'id'          => 'typography-h5',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('H5', 'bionickwp'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('h5'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the Heading font properties.', 'bionickwp'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),	
                        array(
                            'id'          => 'typography-h6',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('H6', 'bionickwp'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('h6'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the Heading font properties.', 'bionickwp'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),	
							array(
			                'id' => 'notice_critical1_permalink1',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => __('Permalink', 'bionickwp'),
			                'desc' => __('', 'doro')
			            ),	
                        array(
                            'id'          => 'typography-lnurl',
                            'type'        => 'typography', 
                            'title'       => __('Link URL', 'bionickwp'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('a'),
                            'units'       =>'px',
                            'subtitle'    => __('Specify the permalink link url font properties.', 'bionickwp'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),							
						),		
						array(
                            'id'          => 'typography-a-hover',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Link URL Hover', 'bionickwp'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('a:focus, a:hover'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the permalink font properties.', 'bionickwp'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),						  
						array(
			                'id' => 'notice_critical13',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_attr__('Page', 'bionickwp'),
			                'desc' => esc_attr__('', 'bionickwp')
			            ),
                        array(
                            'id'          => 'typography-pgtl',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Title', 'bionickwp'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.section-title h2'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the page title font properties.', 'bionickwp'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),	
                        array(
                            'id'          => 'typography-pgsubtl',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Sub Title', 'bionickwp'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.section-title h3'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the page sub title font properties.', 'bionickwp'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),							
						),
                        array(
                            'id'          => 'typography-pgsectl',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Section Title', 'bionickwp'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.bg-title span'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the page section title font properties.', 'bionickwp'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),							
						),  			
                        array(
                            'id'          => 'typography-pgcon',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Content', 'bionickwp'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.sec-text p, p'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the page content font properties.', 'bionickwp'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),							
						),							
						array(
			                'id' => 'notice_critical14',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_attr__('Post', 'bionickwp'),
			                'desc' => esc_attr__('', 'bionickwp')
			            ),	
                        array(
                            'id'          => 'typography-bltl',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Title', 'bionickwp'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('article h4'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the blog post title font properties.', 'bionickwp'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),							
						),						
                        array(
                            'id'          => 'typography-blcon',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Content', 'bionickwp'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('article p'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the blog post content font properties.', 'bionickwp'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),							
						),	
						array(
			                'id' => 'notice_critical16',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_attr__('Portfolio', 'bionickwp'),
			                'desc' => esc_attr__('', 'bionickwp')
			            ),
                        array(
                            'id'          => 'typography-prftl',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Section Title', 'bionickwp'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.fw-title h3'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the portfolio details page section title font properties.', 'bionickwp'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),							
						),	
                        array(
                            'id'          => 'typography-prfdt',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Details Title', 'bionickwp'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.text-title'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the portfolio details page details title font properties.', 'bionickwp'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),							
						),
                        array(
                            'id'          => 'typography-prcon',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Details Content', 'bionickwp'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.project-decr p'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the portfolio details page details content font properties.', 'bionickwp'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),							
						),						
                        array(
                            'id'          => 'typography-prfcon',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Details Info', 'bionickwp'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.pr-list li span, .pr-list li h4'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the portfolio details page details info font properties.', 'bionickwp'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),							
						),	
						array(
			                'id' => 'notice_critical126',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_attr__('Services', 'bionickwp'),
			                'desc' => esc_attr__('', 'bionickwp')
			            ),
                        array(
                            'id'          => 'typography-servtl',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Section Title', 'bionickwp'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.services-box-info h4'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the services section font properties.', 'bionickwp'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),							
						),	
                        array(
                            'id'          => 'typography-servcon',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Section Content', 'bionickwp'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.services-box-info p'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the services section font properties.', 'bionickwp'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),							
						),	
                        array(
                            'id'          => 'typography-servlist',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Section List', 'bionickwp'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.services-box-info ul li'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the services section font properties.', 'bionickwp'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),							
						),	
                        array(
                            'id'          => 'typography-servprice',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Section Price', 'bionickwp'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.services-box-info .price'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the services section font properties.', 'bionickwp'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),							
						),							
						array(
			                'id' => 'notice_critical18',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_attr__('Navigation', 'bionickwp'),
			                'desc' => esc_attr__('', 'bionickwp')
			            ),
                        array(
                            'id'          => 'typography-mainmenu',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Main Menu', 'bionickwp'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.nav-inner nav li a'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the main menu font properties.', 'bionickwp'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),							
						),
                        array(
                            'id'          => 'typography-mainmenusub',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Main Menu Sub Items', 'bionickwp'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.nav-inner nav li ul li a'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the main menu sub items font properties.', 'bionickwp'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),							
						),	
                        array(
                            'id'          => 'typography-homemenu',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Home/One Page Menu', 'bionickwp'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.scroll-nav li a'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the home/one page menu font properties.', 'bionickwp'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),							
						),	
						array(
			                'id' => 'notice_critical17',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_attr__('Intro', 'bionickwp'),
			                'desc' => esc_attr__('', 'bionickwp')
			            ),
                        array(
                            'id'          => 'typography-introtl',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Title', 'bionickwp'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.hero-title h3'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the intro section title font properties.', 'bionickwp'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),							
						),							
                        array(
                            'id'          => 'typography-introsubtl',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Sub Title', 'bionickwp'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.hero-title h4 a, .hero-title h4'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the intro section sub title font properties.', 'bionickwp'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),							
						),	
						array(
			                'id' => 'notice_critical15',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_attr__('Widget', 'bionickwp'),
			                'desc' => esc_attr__('', 'bionickwp')
			            ),
                        array(
                            'id'          => 'typography-pgsdtl',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Sidebar Widget Title', 'bionickwp'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.spo-sidebar-widget-title'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the page sidebar widget title font properties.', 'bionickwp'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),							
						),
                        array(
                            'id'          => 'typography-pgsdcon',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Sidebar Widget Content', 'bionickwp'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.spo-sidebar-widget'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the page sidebar widget content font properties.', 'bionickwp'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),							
						),						
                        array(
                            'id'          => 'typography-pgsdlst',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Sidebar Widget List Items', 'bionickwp'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.spo-sidebar-widget ul li'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the page sidebar widget list items font properties.', 'bionickwp'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),							
						),						
                        array(
                            'id'          => 'typography-pgsdln',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Sidebar Widget Link', 'bionickwp'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.spo-sidebar-widget ul li a'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the page sidebar widget link font properties.', 'bionickwp'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),							
						),						


               
                     						
						
                    )
               ) );				
				
				 Redux::setSection( $opt_name, array(
                    'icon'   => 'el-icon-list',
                    'title'  => esc_attr__( 'Footer Settings', 'bionickwp' ),
                    'fields' => array(														
					
					array(
							'id' => 'copyright',
							'type' => 'editor',
							'wpautop'=>true,
							'compiler' => 'true',
							'title' => esc_attr__('Copyright text of the Website', 'bionickwp'),
							'subtitle' => esc_attr__('Inser Copyright text here.', 'bionickwp'),
							'default'          => '<span> &#169; Bionick 2015 Developed by <a href="http://webredox.net" target="_blank">webRedox</a></span> | All rights reserved.',
							'args'   => array(
								'teeny'            => true,
								'textarea_rows'    => 10
							)
					),
			
					)
                ));
				
				
				 Redux::setSection( $opt_name, array(
                    'icon'   => 'el-icon-key',
                    'title'  => esc_attr__( 'Documentation', 'bionickwp' ),
                    'fields' => array(					
					
					array(
							'id' => 'docs',
							'type' => 'info',
		                    'notice' => true,
		                    'style' => 'info',
							'title' => esc_attr__('Bionick Theme Documentation', 'bionickwp'),
							'desc' => __('<a href="http://webredox.net/demo/wp/bionick/doc/documentation.html" target="_blank">Click Here</a> To get the theme documentation.', 'bionickwp')
							
					),	

			
			
					)
                ));	
    /*
     * <--- END SECTIONS
     */

    /**
     * This is a test function that will let you see when the compiler hook occurs.
     * It only runs if a field    set with compiler=>true is changed.
     * */
    if ( ! function_exists( 'compiler_action' ) ) {
        function compiler_action( $options, $css, $changed_values ) {
            echo '<h1>The compiler hook has run!</h1>';
            echo "<pre>";
            print_r( $changed_values ); // Values that have changed since the last save
            echo "</pre>";
            //print_r($options); //Option values
            //print_r($css); // Compiler selector CSS values  compiler => array( CSS SELECTORS )
        }
    }

    /**
     * Custom function for the callback validation referenced above
     * */
    if ( ! function_exists( 'redux_validate_callback_function' ) ) {
        function redux_validate_callback_function( $field, $value, $existing_value ) {
            $error   = false;
            $warning = false;

            //do your validation
            if ( $value == 1 ) {
                $error = true;
                $value = $existing_value;
            } elseif ( $value == 2 ) {
                $warning = true;
                $value   = $existing_value;
            }

            $return['value'] = $value;

            if ( $error == true ) {
                $return['error'] = $field;
                $field['msg']    = 'your custom error message';
            }

            if ( $warning == true ) {
                $return['warning'] = $field;
                $field['msg']      = 'your custom warning message';
            }

            return $return;
        }
    }

    /**
     * Custom function for the callback referenced above
     */
    if ( ! function_exists( 'redux_my_custom_field' ) ) {
        function redux_my_custom_field( $field, $value ) {
            print_r( $field );
            echo '<br/>';
            print_r( $value );
        }
    }

    /**
     * Custom function for filtering the sections array. Good for child themes to override or add to the sections.
     * Simply include this function in the child themes functions.php file.
     * NOTE: the defined constants for URLs, and directories will NOT be available at this point in a child theme,
     * so you must use get_template_directory_uri() if you want to use any of the built in icons
     * */
    if ( ! function_exists( 'dynamic_section' ) ) {
        function dynamic_section( $sections ) {
            //$sections = array();
            $sections[] = array(
                'title'  => esc_attr__( 'Section via hook', 'bionickwp' ),
                'desc'   => esc_attr__( '<p class="description">This is a section created by adding a filter to the sections array. Can be used by child themes to add/remove sections from the options.</p>', 'bionickwp' ),
                'icon'   => 'el el-paper-clip',
                // Leave this as a blank section, no options just some intro text set above.
                'fields' => array()
            );

            return $sections;
        }
    }

    /**
     * Filter hook for filtering the args. Good for child themes to override or add to the args array. Can also be used in other functions.
     * */
    if ( ! function_exists( 'change_arguments' ) ) {
        function change_arguments( $args ) {
            //$args['dev_mode'] = true;

            return $args;
        }
    }

    /**
     * Filter hook for filtering the default value of any given field. Very useful in development mode.
     * */
    if ( ! function_exists( 'change_defaults' ) ) {
        function change_defaults( $defaults ) {
            $defaults['str_replace'] = 'Testing filter hook!';

            return $defaults;
        }
    }
